antares.apps.message package — Antares 0.0.2 documentation

# antares.apps.message package

## Subpackages

- antares.apps.message.api package
  - Submodules
  - antares.apps.message.api.message_api module
  - antares.apps.message.api.message_details_api module
  - Module contents
- antares.apps.message.migrations package
  - Submodules
  - antares.apps.message.migrations.0001_initial module
  - antares.apps.message.migrations.0002_auto_20180624_1759 module
  - Module contents
- antares.apps.message.models package
  - Submodules
  - antares.apps.message.models.message module
  - antares.apps.message.models.message_status module
  - Module contents
- antares.apps.message.serializers package
  - Submodules
  - antares.apps.message.serializers.message_serializer module
  - Module contents
- antares.apps.message.service package
  - Submodules
  - antares.apps.message.service.message_manager module
  - Module contents
- antares.apps.message.tests package
  - Submodules
  - antares.apps.message.tests.test_message_manager module
  - Module contents

## Submodules

## antares.apps.message.admin module

## antares.apps.message.apps module

class `antares.apps.message.apps.` `MessageConfig`(app_name, app_module)

  Bases: `django.apps.config.AppConfig`

  `name` = 'message'

## antares.apps.message.constants module

## antares.apps.message.urls module

## Module contents